@@ -15,6 +15,7 @@
 #include "dirs.H"
 #include "auswahl.h"
 #include "ConfigFile.H"
+#include "commonElements.H"
 #include <wx/image.h>
 #include <wx/event.h>
 
@@ -27,29 +28,36 @@ END_EVENT_TABLE()
 Auswahldialog::Auswahldialog(wxWindow* parent, wxWindowID id,
 			     const wxString& title, const wxPoint& pos, 
 			     const wxSize& size, long style, const wxString& name)
-  : wxDialog(parent, id, title, pos, size, style, name),
-    btnLL(this, LL, _("&Lesson...")),
-    btnKL(this, KL, _("&Class...")),
-    btnCS(this, CS, _("&Do the contest...")),
-    btnCancel(this, wxID_CANCEL, _("Cancel"))
+  : wxDialog(parent, id, title, pos, size, style, name)
 {
-  LessonDir logopath;
-  logopath.SetFullName( _T("logo.png"));
-  this->logo = new wxBitmap(logopath.GetFullPath(), wxBITMAP_TYPE_PNG);
-  this->canvas = new MyCanvas(this, logo,
-			      wxDefaultPosition,
-			      wxSize(logo->GetWidth(),
-				     logo->GetHeight()));
+  this->logo = common::getLogo();
+
+  this->btnLL = new wxButton(this, LL, _("&Lesson..."));
+  this->btnLL->SetToolTip(_("Click here to start with a single lesson of your choice"));
+  this->btnKL = new wxButton(this, KL, _("&Class..."));
+  this->btnKL->SetToolTip(_("Click here to start in a new class or continue with an old one"));
+  this->btnCS = new wxButton(this, CS, _("&Do the contest..."));
+  this->btnCS->SetToolTip(_("Click here to do the contest... isn't this tip amazing?! ;-)"));
+  this->btnCancel = new wxButton(this, wxID_CANCEL, _("Cancel"));
+  this->btnCancel->SetToolTip(_("Dismiss this dialog"));
+
   wxBoxSizer* buttonSizer = new wxBoxSizer (wxVERTICAL);
-  buttonSizer->Add(&this->btnLL,1,wxEXPAND|wxALL,5);
-  buttonSizer->Add(&this->btnKL,1,wxEXPAND|wxALL,5);
-  if (TtConfigFile::getPtr()->contestsExist() == true) {
-    buttonSizer->Add(&this->btnCS,1,wxEXPAND|wxALL,5);
+  buttonSizer->Add(this->btnLL,1,wxEXPAND|wxALL,5);
+  buttonSizer->Add(this->btnKL,1,wxEXPAND|wxALL,5);
+  if (TtConfigFile::getPtr()->contestsExist()) {
+    buttonSizer->Add(this->btnCS,1,wxEXPAND|wxALL,5);
+  } else {
+    btnCS->Hide();
   }
-  buttonSizer->Add(&this->btnCancel,1,wxEXPAND|wxALL,5);
+  buttonSizer->Add(this->btnCancel,1,wxEXPAND|wxALL,5);
 
   wxBoxSizer* dialogSizer = new wxBoxSizer (wxHORIZONTAL);
-  dialogSizer->Add(this->canvas);
+  if (this->logo != 0) {
+    dialogSizer->Add(new MyCanvas(this, logo,
+				  wxDefaultPosition,
+				  wxSize(logo->GetWidth(),
+					 logo->GetHeight())));
+  }
   dialogSizer->Add(buttonSizer,0,wxEXPAND/*|wxALIGN_CENTER*/|wxALL,10);
 
   SetSizer(dialogSizer);
@@ -57,8 +65,6 @@ Auswahldialog::Auswahldialog(wxWindow* parent, wxWindowID id,
 }
 
 Auswahldialog::~Auswahldialog () {
-  delete this->logo;
-  this->canvas->Destroy();
 }
 
 void Auswahldialog::OnButton (wxCommandEvent& event) {
