@@ -34,12 +34,11 @@ class Auswahldialog : public wxDialog {
   void OnButton(wxCommandEvent& event);
 
  private:
-  wxButton btnLL;
-  wxButton btnKL;
-  wxButton btnCS;
-  wxButton btnCancel;
+  wxButton* btnLL;
+  wxButton* btnKL;
+  wxButton* btnCS;
+  wxButton* btnCancel;
   wxBitmap* logo;
-  MyCanvas* canvas;
 
   DECLARE_EVENT_TABLE()
 };
