@@ -14,43 +14,44 @@
 
 #include "dirs.H"
 #include "info.h"
-#include "../config.h"
+#include "commonElements.H"
 #include <wx/image.h>
 
+#ifndef __VISUALC__
+#  include "../config.h"
+#endif
+
 BEGIN_EVENT_TABLE(Info_Dialog, wxDialog)
 END_EVENT_TABLE()
 
 Info_Dialog::Info_Dialog(wxWindow* parent)
-  : wxDialog(parent, -1, _("About PingoS Tipptrainer")),
-    BtnClose(this, wxID_CANCEL, _("Close"))
+  : wxDialog(parent, -1, wxString(_("About PingoS Tipptrainer")))
 {
+  this->BtnClose = new wxButton(this, wxID_CANCEL, wxString(_("Close")));
   wxBoxSizer* dialogSizer = new wxBoxSizer(wxVERTICAL);
   wxBoxSizer* topSizer = new wxBoxSizer(wxHORIZONTAL);
   wxBoxSizer* bottomSizer = new wxBoxSizer(wxHORIZONTAL);
 
-  LessonDir logopath;
-  logopath.SetFullName(_T("logo.png"));
-  this->logo = new wxBitmap(logopath.GetFullPath(), wxBITMAP_TYPE_PNG),
-  this->canvas = new MyCanvas(this,this->logo,
-			      wxDefaultPosition,
-			      wxSize(this->logo->GetWidth(),
-				     this->logo->GetHeight()));
-  topSizer->Add(canvas,0,wxALIGN_CENTER|wxRIGHT,10);
-
+  this->logo = common::getLogo();
+  if (this->logo != 0) {
+    topSizer->Add(new MyCanvas(this,this->logo,wxDefaultPosition,
+			       wxSize(this->logo->GetWidth(),
+				      this->logo->GetHeight())),
+		  0,wxALIGN_CENTER|wxRIGHT,10);
+  }
   wxString msg;
-  msg << _T("PingoS Tipptrainer\n")
-      << _T("------------------\n")
-      <<  _("Version") << _T(":      ") << wxString::FromAscii(PACKAGE_VERSION)
-      << _T("\nhttp://www.pingos.org/tipptrainer/\n")
-      <<  _("Licenced with the GPL 2.0")
+  msg <<  _("Version") << _T(": ") << wxString::FromAscii(PACKAGE_VERSION) << _T("\n")
+      <<  _("Homepage") << _T(": ") << _T("http://www.pingos.org/tipptrainer/") << _T("\n")
+      <<  _("Licence") << _T(": ") << _T("GPL 2.0") << _T("\n")
       << _T("\n\n")
-      <<  _("Authors:")
-      << _T("\n")
-      << _T("   Daniel Reith <DanR@gmx.de>\n")
+      <<  _("Current authors:") << _T("\n")
       << _T("   Hendrik Sattler <pingos@hendrik-sattler.de>\n")
       << _T("   Heiko Degenhardt <hede@pingos.org>\n")
-      << _T("   Torsten Hemm <T.Hemm@gmx.de>\n")
       << _T("   Andreas Kalbitz <felix@musik-workshop.de>\n")
+      << _T("\n")
+      <<  _("Previous authors:") << _T("\n")
+      << _T("   Daniel Reith <DanR@gmx.de>\n")
+      << _T("   Torsten Hemm <T.Hemm@gmx.de>\n")
       << _T("   Matthias Kleine <Matthias.Kleine@selflinux.de>\n")
       << _T("\n\n")
       <<  _("Please send feedback to") << _T("  ") << wxString::FromAscii(PACKAGE_BUGREPORT);
@@ -58,7 +59,7 @@ Info_Dialog::Info_Dialog(wxWindow* parent)
   this->message = new wxStaticText(this, -1, msg);
   topSizer->Add(this->message,1,wxALIGN_RIGHT|wxALL,10);
   
-  bottomSizer->Add(&this->BtnClose,0,wxALL,10);
+  bottomSizer->Add(this->BtnClose,0,wxALL,10);
 
   dialogSizer->Add(topSizer,1,wxALIGN_TOP);
   dialogSizer->Add(bottomSizer,0,wxALIGN_CENTER);
@@ -66,12 +67,11 @@ Info_Dialog::Info_Dialog(wxWindow* parent)
   
   //initialize the dialog behaviour
   SetSizer(dialogSizer);
-  this->BtnClose.SetFocus();
+  this->BtnClose->SetFocus();
 }
 
 Info_Dialog::~Info_Dialog () {
   delete this->logo;
-  this->canvas->Destroy();
   this->message->Destroy();
 }
 
