@@ -38,11 +38,10 @@ class Info_Dialog : public wxDialog {
 
  private:
   wxBitmap* logo;
-  MyCanvas* canvas;
   wxStaticText* message;
   // Added this button to give it the focus during dialog
   // creation:
-  wxButton BtnClose;
+  wxButton* BtnClose;
 
  DECLARE_EVENT_TABLE()
 };
