@@ -19,100 +19,94 @@
 #include <wx/settings.h>
 
 BEGIN_EVENT_TABLE(TtInputControl, wxTextCtrl)
+  EVT_KEY_DOWN(TtInputControl::onKeyDown)
   EVT_CHAR(TtInputControl::onChar)
-//   EVT_MOUSE_EVENTS(TtInputControl::onMouse)
+  EVT_MOUSE_EVENTS(TtInputControl::onMouse)
 END_EVENT_TABLE()
 
 TtInputControl::TtInputControl (wxWindow* parent)
   : wxTextCtrl(parent, 2, _T(""), wxDefaultPosition, wxDefaultSize,
-	       wxNO_BORDER|wxTE_MULTILINE|wxTE_PROCESS_TAB/*|wxTE_RICH*/) {
-  
-  //Pointer auf Hauptfenster
-  hauptfenster=(wxFrame*)GetParent()->GetParent();
-  m_falsch=false;
-
+	           wxNO_BORDER|wxTE_MULTILINE|wxTE_READONLY|wxTE_RICH2|wxTE_PROCESS_TAB)
+{
   //black text color
-  this->textcolor = wxBLACK;
+  this->textcolor = new wxColor(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
   //white background color
-  this->bgcolor = wxWHITE;
+  this->bgcolor = new wxColor(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW));
   this->localfont = NULL;
-  wxFont* f = TtConfigFile::getPtr()->getMainWindowFont();
-  setFont(*f);
+  wxFont f = TtConfigFile::getPtr()->getMainWindowFont();
+  setFont(f);
 }
 
 TtInputControl::~TtInputControl () {
 }
 
-void  TtInputControl::onChar (wxKeyEvent& event) {
-  if (event.m_altDown) {
+void TtInputControl::onKeyDown (wxKeyEvent& event) {
+  if (event.AltDown()) {
     event.Skip();
     return;
   }
-  Hauptfenster* haupt = (Hauptfenster*) hauptfenster;
-  // Falls keine Lektion geladen, wird auch nicht die Richtigkeit der Eingabe getestet, es ist keine Eingabe mglich
-  if (haupt->getLessonController() == 0 ||
-      !haupt->getLessonController()->runningLesson()) {
+
+  if (!IsEditable()) {
     return;
   }
 
-  // Abfangen unerwnschter Tasten, wie z.B. die Pfeiltasten
-  switch (event.KeyCode()) {
-  case WXK_BACK:
+  Hauptfenster* haupt = Hauptfenster::getPtr();
+  this->lesson = haupt->getLessonController()->getLesson();
+  int keycode = event.GetKeyCode();
+  switch (keycode) {
   case WXK_LEFT:
   case WXK_DOWN:
   case WXK_RIGHT:
   case WXK_UP:
-  case WXK_END:
   case WXK_HOME:
-  case WXK_CLEAR:
+  case WXK_END:
+  case WXK_DELETE:
+  case WXK_INSERT:
   case WXK_PRIOR:
   case WXK_NEXT:
+    /* Here are keys that are definitely wrong
+     * but shall not increase the wrong key counter
+     */
+    haupt->SetStatusText(wxString(_("Wrong"))
+			 + wxString(_T(' '))
+			 + wxString(_("(excluded from false counter)")));
     if (TtConfigFile::getPtr()->getBellStatus()) {
       wxBell();
     }
+    //don't skip
+    break;
+  case WXK_BACK:
+    this->lesson->checkInput(keycode); //never true so far
+    //don't skip
+    break;
+  case WXK_RETURN:
+    //do it here instead of skip (else broken behaviour on Win32 with wxTE_RICH2)
+    this->lesson->checkInput('\n');
     break;
   default:
-    if (haupt->getLessonController()->getLesson()->Eingabe(event.KeyCode())) {
-      hauptfenster->SetStatusText(_("Correct"));
-      // sonst kann man kein Enter drcken
-      wxString s;
-      if (event.KeyCode()==WXK_RETURN) {
-	if (this->specialLineEndingChar) {
-	  s << wxChar(182);
-	}
-	s << wxChar(_T('\n'));
-      } else {
-	s << wxChar(event.KeyCode());
-      }
-      // Durch diese if Anweisung werden Fehler markiert. Da der falsche Buchstabe aber nicht gezeichnet wird, 
-      // brauchen wir die Hilfsvariable bool m_falsch
-      if (m_falsch) {
-	this->bgcolor=wxRED;
-	updateLook();
-	this->m_falsch=false;
-      } else {
-	this->bgcolor=wxWHITE;
-	updateLook();
-      }
-      *this << s;
-      if (haupt->GetOutput()->getHighlightPosition() >= haupt->GetOutput()->GetLastPosition()) {
-	haupt->SetStatusText(_("Lesson finished"));
-	haupt->getLessonController()->getLesson()->SetEnde();
-	haupt->getLessonController()->getLesson()->LektionEnde();
-      }
-    } else {
-      if (TtConfigFile::getPtr()->getBellStatus()) {
-	wxBell();
-      }
-      hauptfenster->SetStatusText(_("Wrong"));
-      m_falsch=true;
-    }
+    event.Skip(); // will result in a wxEVT_CHAR
     break;
   } 
 }
 
+void TtInputControl::onChar (wxKeyEvent& event) {
+  if (event.AltDown()) {
+    event.Skip();
+    return;
+  }
+  int keycode = event.GetKeyCode();
+  this->lesson->checkInput(keycode);
+}
+
+void TtInputControl::appendChar (wxUChar c) {
+  if (c == wxUChar(_T('\n')) &&
+      this->specialLineEnd != 0) {
+    *this << (wxChar)this->specialLineEnd;
+  }
+  *this << (wxChar)c;
+}
+
 /* On Mouse action, ignore all specialties but give focus
- *
  * I found an error (maybe on with KDE3) where MOUSE_DCLICK
  * is not catched.
  */
@@ -130,13 +124,10 @@ void TtInputControl::updateLook () {
 //   SetStyle(0,GetLastPosition(),attribs);
 }
 
+#include "commonElements.H"
+
 void TtInputControl::setFont (wxFont& newFont) {
-  if (newFont.GetEncoding() == wxFONTENCODING_ISO8859_1 ||
-      newFont.GetEncoding() == wxFONTENCODING_ISO8859_15) {
-    this->specialLineEndingChar=true;
-  } else {
-    this->specialLineEndingChar=false;
-  }
+  this->specialLineEnd=common::specialLineEnd(newFont.GetEncoding());
   if (this->localfont != NULL) {
     delete this->localfont;
   }
