@@ -15,32 +15,42 @@
 #ifndef INPUTCONTROL_H
 #define INPUTCONTROL_H
 
+#include "lektion.h"
 #include <wx/wx.h>
 
 class TtInputControl : public wxTextCtrl {
 public:
-  TtInputControl(wxWindow* parent);
-  ~TtInputControl();
+  TtInputControl (wxWindow* parent);
+  ~TtInputControl ();
 
-  void onChar(wxKeyEvent& event);
-  void onMouse(wxMouseEvent& event);
+  void onKeyDown (wxKeyEvent& event);
+  void onChar (wxKeyEvent& event);
+  void onMouse (wxMouseEvent& event);
+  void onEnter (wxCommandEvent& e);
 
   void Clear();
 
   void setFont (wxFont& newFont);
   inline wxFont* getFont () { return localfont; };
 
+  void setBgColor (wxColor* newColor) { bgcolor= newColor; };
+  wxColor* getBgColor () { return bgcolor; };
+
+  void setTextColor (wxColor* newColor) { textcolor= newColor; };
+  wxColor* getTextColor () { return textcolor; };
+
+  void appendChar (wxUChar c);
+  void updateLook ();
+
 private:
   wxFont* localfont;
   wxColour* textcolor;
   wxColour* bgcolor;
 
-  bool specialLineEndingChar;
+  wxUChar specialLineEnd;
 
-  void updateLook ();
-
-  bool m_falsch; 
-  wxFrame* hauptfenster;
+  //steadily updated
+  Lektion* lesson;
 
   DECLARE_EVENT_TABLE()  
 };
