@@ -35,8 +35,9 @@ BEGIN_EVENT_TABLE(Kurs,LessonController)
   LESSON_FINISH(wxID_ANY, Kurs::onLessonFinish)
 END_EVENT_TABLE()
 
-Kurs::Kurs (wxWindow* parent) {
-  this->parent = parent;
+Kurs::Kurs (wxWindow* parent)
+  : parent(parent)
+{
   controllerName=_("class");
   lesson=0;
   if (!Hauptfenster::getPtr()->setLessonController(this)) {
@@ -65,7 +66,6 @@ Kurs::Kurs (wxWindow* parent) {
     break;
   }
   delete kd;
-
 }
 
 Kurs::~Kurs () {
@@ -75,40 +75,41 @@ Kurs::~Kurs () {
   }
 }
 
+#include "commonElements.H"
+#include <wx/tokenzr.h>
+
 bool Kurs::ladeKursKriterien () {
-  wxString* tlayout = TtConfigFile::getPtr()->getKeyboardLayout();
-  LessonDir f;
-  f.AppendDir(*tlayout);
-  delete tlayout;
-  f.SetName(_T("kurs"));
+  bool retval = true;
+  LessonPath f;
+  f.appendDir(TtConfigFile::getPtr()->getKeyboardLayout());
+  f.setFileName(_T("kurs"));
   wxString filename;
   filename << this->kn;
-  f.SetExt(filename);
+  f.setFileExt(filename);
 
-  wxFFileInputStream input(f.GetFullPath());
-  if (!input.Ok()) {
-    ::wxLogError(_("Cannot load file %s"), f.GetFullName().c_str());
-    return false;
+  wxURL* u = f.getURL();
+  wxInputStream* input = common::getInputStream(*u);
+  if (input==0) {
+    ::wxLogError(_("Cannot load file %s"), f.getFullFileName().c_str());
+    retval=false;
   } else {
-    wxTextInputStream f(input);
-    wxString s;
-    long t,u,v;
-    int i,j;
-    while(!input.Eof()) {
-      s=f.ReadLine();
-      if (!input.Eof()) {
-	if ((i=s.Find(_T(':')))!=-1 &&
-	    (j=s.Find(_T(':'),true))!=-1 &&
-	    i!=j) {
-	  s(0,i).ToLong(&t);
-	  s(i+1,j-i).ToLong(&u);
-	  s(j+1,s.Length()-j+1).ToLong(&v);
-	  this->kriterien.push_back(LKrit(t,u,v));
-	}
-      }
+    wxArrayString ar = common::getIndexFile(*input);
+    wxStringTokenizer t;
+    long num,time,mil;
+    for (unsigned int i=0; i<ar.GetCount(); ++i) {
+      t.SetString(ar[i],wxString(_T(":")),wxTOKEN_RET_EMPTY_ALL);
+      num=0;
+      t.GetNextToken().ToLong(&num);
+      time=0;
+      t.GetNextToken().ToLong(&time);
+      mil=0;
+      t.GetNextToken().ToLong(&mil);
+      this->kriterien.push_back(LKrit(num, time, mil));
     }
   }
-  return true;
+  delete input;
+  delete u;
+  return retval;
 }
 
 
@@ -138,6 +139,7 @@ bool Kurs::KursBeginnen () {
   this->akt_krit = 0;
   KursEinleitung();
   LKrit t = this->kriterien[akt_krit];
+  lesson = 0;
   lesson = new Lektion(t.getNummer(), this);
   return true;
 }
@@ -153,6 +155,7 @@ bool Kurs::KursLaden () {
   // Die Lektion, die nun dran ist laden.
   if (this->akt_krit <  this->kriterien.size()) {
     LKrit t = this->kriterien[this->akt_krit];
+    lesson = 0;
     lesson = new Lektion(t.getNummer(), this);
   } else {
     KursEnde();
@@ -177,6 +180,8 @@ void Kurs::NaechsteLektion (const LEntry& ldata) {
     }
     //no break
   case PREV_B:
+    delete lesson;
+    lesson = 0;
     try {
       lesson = new Lektion(this->kriterien[this->akt_krit].getNummer(),
 			   this);
@@ -192,44 +197,44 @@ void Kurs::NaechsteLektion (const LEntry& ldata) {
 }
 
 bool Kurs::KursEinleitung () {
-  wxString* tlayout = TtConfigFile::getPtr()->getKeyboardLayout();
-  LessonDir f;
-  f.AppendDir(*tlayout);
-  delete tlayout;
-  f.SetName(_T("kurs"));
+  LessonPath f;
+  f.appendDir(TtConfigFile::getPtr()->getKeyboardLayout());
+  f.setFileName(_T("kurs"));
   wxString filename(_T("a"));
   filename << this->kn;
-  f.SetExt(filename);
+  f.setFileExt(filename);
 
-  wxString s;
-  wxFFile file(f.GetFullPath());
-  if (file.IsOpened()) {
-    file.ReadAll(&s);
+  wxURL* u = f.getURL();
+  wxInputStream* input = common::getInputStream(*u);
+  if (input==0) {
+    ::wxLogError(_("Cannot load file %s"), f.getFullFileName().c_str());
   } else {
-    ::wxLogError(_("Cannot load file %s"), f.GetFullName().c_str());
-  }
-  wxMessageBox(s , _("Class intro"));
+    wxString s = common::readTextAll (*input);
+    wxMessageBox(s , _("Class intro"));
+  }    
+  delete input;
+  delete u;
   return true;
 }
 
 bool Kurs::KursEnde () {
-  wxString* tlayout = TtConfigFile::getPtr()->getKeyboardLayout();
-  LessonDir f;
-  f.AppendDir(*tlayout);
-  delete tlayout;
-  f.SetName(_T("kurs"));
+  LessonPath f;
+  f.appendDir(TtConfigFile::getPtr()->getKeyboardLayout());
+  f.setFileName(_T("kurs"));
   wxString filename(_T("e"));
   filename << this->kn;
-  f.SetExt(filename);
+  f.setFileExt(filename);
 
-  wxString s;
-  wxFFile file(f.GetFullPath());
-  if (file.IsOpened()) {
-    file.ReadAll(&s);
+  wxURL* u = f.getURL();
+  wxInputStream* input = common::getInputStream(*u);
+  if (input == 0) {
+    ::wxLogError(_("Cannot load file %s"), f.getFullFileName().c_str());
   } else {
-    ::wxLogError(_("Cannot load file %s"), f.GetFullName().c_str());
-  }
-  wxMessageBox(s, _("End of class"));
+    wxString s = common::readTextAll(*input);
+    wxMessageBox(s, _("End of class"));
+  }    
+  delete input;
+  delete u;
   return true;
 }
 
@@ -276,7 +281,5 @@ void Kurs::onLessonAbort (wxCommandEvent& WXUNUSED(e)) {
 
 void Kurs::onLessonFinish (wxCommandEvent& WXUNUSED(e)) {
   LEntry ldata(lesson->GetLessonData());
-  delete lesson;
-  lesson = 0;
   NaechsteLektion(ldata);
 }
