@@ -15,6 +15,7 @@
 #include "dirs.H"
 #include "kurslaus.h"
 #include "KLessonStatusSizer.H"
+#include "commonElements.H"
 #include <wx/sizer.h>
 #include <wx/statline.h>
 
@@ -23,21 +24,23 @@ BEGIN_EVENT_TABLE(kurslaus,wxDialog)
 END_EVENT_TABLE()
 
 kurslaus::kurslaus(wxWindow *parent, const LEntry& entry, const LKrit& krit)
-  : wxDialog(parent, -1, _T(""))
+  : wxDialog(parent, -1, wxString(_T("")),
+	     wxDefaultPosition, wxDefaultSize,
+	     wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER)
 {
   wxString t;
   t.Printf(_("Statistics for Lesson %d"), krit.getNummer());
   SetTitle(t);
-  LessonDir f;
-  f.SetFullName(_T("logo.png"));
-  wxBitmap logo(f.GetFullPath(), wxBITMAP_TYPE_PNG);
-  wxStaticBitmap *icon = new wxStaticBitmap(this, -1, logo);
 
   KLessonStatusSizer* statusSizer = new KLessonStatusSizer(this);
   statusSizer->setStatus(entry,krit);
 
+  wxBitmap* logo = common::getLogo();
   wxBoxSizer* subSizer = new wxBoxSizer(wxHORIZONTAL);
-  subSizer->Add(icon,0,wxLEFT|wxRIGHT|wxTOP,10);
+  if (logo != 0) {
+    subSizer->Add(new wxStaticBitmap(this, -1, *logo),
+		  0,wxLEFT|wxRIGHT|wxTOP,10);
+  }
   subSizer->Add(statusSizer,0,wxALIGN_CENTER|wxRIGHT|wxTOP,10);
 
   wxBoxSizer* buttonSizer = new wxBoxSizer(wxHORIZONTAL);
