@@ -1,48 +1,38 @@
 /***************************************************************************
-                          kurslaus.h  -  description                              
-                             -------------------                                         
-    begin                : Fri Jun  2 21:55:28 MEST 2000 
-                                           
-    copyright            : (C) 1999 by Daniel Reith                         
-    email                : DanR@gmx.de
-	
- ***************************************************************************/
-
-/***************************************************************************
+ *   copyright            : (C) 1999 by Daniel Reith                       *
+ *   email                : DanR@gmx.de                                    *
+ *                                                                         *
+ *   copyright           : (C) 2003 by Hendrik Sattler                     *
+ *   mail                : pingos@hendrik-sattler.de                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
 #ifndef KURSLAUS_H
 #define KURSLAUS_H
 
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
+#include "kurs.h"
+#include "lektion.h"
 #include <wx/wx.h>
 #include <wx/grid.h>
 
-#include "kurs.h"
-#include "lektion.h"
+class kurslaus : public wxDialog {
+public:
+  kurslaus(wxWindow *parent, const LEntry& entry, const LKrit& krit);
+
+private:
+  void onButton (wxCommandEvent& e);
 
-class kurslaus: public wxDialog
-{
   DECLARE_EVENT_TABLE()
- private:
-  wxStaticText *m_text;
-  wxGrid *m_grid;
-  wxButton *m_OK;
-  wxButton *m_Cancel;
- public:
-  kurslaus(wxWindow *parent, Lektion *lektion, LKrit krit);
-  void OnOK(wxCommandEvent* event);
-  void OnCancel(wxCommandEvent* event);  
+};
+
+enum {
+  NEXT_B = 1,
+  PREV_B
 };
 
 #endif
