@@ -15,6 +15,7 @@
 #include "dirs.H"
 #include "ConfigFile.H"
 #include "lektionsanweisung.h"
+#include "commonElements.H"
 #include <wx/sizer.h>
 #include <wx/statline.h>
 #include <wx/image.h>
@@ -28,43 +29,42 @@ LessonStartDlg::LessonStartDlg(wxWindow* parent, int Lektion, wxString k,
     lektion(Lektion)
 {
   //read the picture path and add the picture
-  wxString* tlayout = TtConfigFile::getPtr()->getKeyboardLayout();
-  LessonDir f;
-  f.AppendDir(*tlayout);
+  LessonPath f;
+  f.appendDir(TtConfigFile::getPtr()->getKeyboardLayout());
   wxString s(_T("lektion"));
   s << Lektion;
-  f.SetName(s);
-  f.SetExt(_T("png"));
-  wxBitmap logo(f.GetFullPath(), wxBITMAP_TYPE_PNG);
-  if (!logo.Ok()) {
-    wxString error;
-    error.Printf(_("Cannot load file %s"), f.GetFullName().c_str());
-    ::wxLogError(error);
-  }
-  this->icon = new wxStaticBitmap(this, -1, logo);
+  f.setFileName(s);
+  f.setFileExt(_T("png"));
 
-  f.SetName(_T("lektion"));
+  wxBitmap* bmp = common::getBitmap(f);
+
+  f.setFileName(_T("lektion"));
   s.Empty();
   s << _T("a") << Lektion;
-  f.SetExt(s);
-  
-  //load and insert the text
+  f.setFileExt(s);
+
+  wxURL* u = f.getURL();
+  wxInputStream* stream = common::getInputStream(*u);
   wxString text;
-  wxFFile file(f.GetFullPath());
-  if (file.IsOpened()) {
-    file.ReadAll(&text);
+  if (stream == 0) {
+    ::wxLogError(_("Cannot load file %s"), f.getFullFileName().c_str());    
   } else {
-    wxString error;
-    error.Printf(_("Cannot load file %s"), f.GetFullName().c_str());
-    ::wxLogError(error);
+    //load and insert the text
+    text = common::readTextAll(*stream);
   }
-  if (k!=_T("")) {
+  delete stream;
+  delete u;
+
+  if (k != _T("")) {
     text << _T("\n") << k;
   }
 
   //arrange the elements
   wxBoxSizer *dialogSizer = new wxBoxSizer(wxVERTICAL);
-  dialogSizer->Add(icon, 0, wxLEFT|wxRIGHT|wxTOP|wxALIGN_CENTRE,10);
+  if (bmp != 0) {
+    dialogSizer->Add(new wxStaticBitmap(this, -1, *bmp), 
+		     0, wxLEFT|wxRIGHT|wxTOP|wxALIGN_CENTRE,10);
+  }
   dialogSizer->Add(CreateTextSizer(text),0,
 		   wxEXPAND|wxLEFT|wxRIGHT|wxTOP,10);
   dialogSizer->Add(new wxStaticLine(this,-1),0,
@@ -77,5 +77,4 @@ LessonStartDlg::LessonStartDlg(wxWindow* parent, int Lektion, wxString k,
 }
 
 LessonStartDlg::~LessonStartDlg () {
-  delete this->icon;
 }
