@@ -35,12 +35,14 @@ END_EVENT_TABLE()
 
 
 Lektionsauswahl::Lektionsauswahl (wxWindow* parent)
-  : wxDialog(parent, -1, _("Lesson selection"))
+  : wxDialog(parent, -1, wxString(_("Lesson selection")),
+	     wxDefaultPosition, wxDefaultSize,
+	     wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER)
 {
   this->notebook = new wxNotebook(this,NOTEBOOK,wxDefaultPosition,
 				  wxDefaultSize,wxNB_TOP);
   this->notebook->AddPage(getIncludedLessonPage(this->notebook),
-			  _("Build-in lessons"), false);
+			  _("Built-in lessons"), false);
   this->notebook->AddPage(getAddonLessonPage(this->notebook),
 			  _("Add-on lessons"), false);
   wxNotebookSizer* nbs = new wxNotebookSizer(notebook);
@@ -87,8 +89,9 @@ wxPanel* Lektionsauswahl::getIncludedLessonPage (wxWindow* parent) {
   wxPanel* panel = new wxPanel(parent);
 
   //listbox for the lessons
-  lb = getIncludedLessonListBox(panel, LB);
-  lb->SetSelection(0);
+  this->lb = getIncludedLessonListBox(panel, LB);
+  this->lb->SetSelection(0);
+  this->lb->SetToolTip(_("Choose the lesson that you would like to train on"));
 
   //creating a sub sizer
   this->sb = new wxStaticBox(panel, -1, _("Lesson status"));
@@ -108,10 +111,10 @@ wxPanel* Lektionsauswahl::getIncludedLessonPage (wxWindow* parent) {
   lektionsSizer->Add(lb,1,wxEXPAND);
   lektionsSizer->Add(new wxStaticLine(panel,-1,wxDefaultPosition,wxDefaultSize,wxLI_VERTICAL),
 		     0,wxEXPAND|wxLEFT|wxRIGHT,10);
-  lektionsSizer->Add(sbSizer,0,wxEXPAND);
+  lektionsSizer->Add(sbSizer,0,wxALIGN_CENTER);
 
   wxBoxSizer* panelSizer = new wxBoxSizer (wxVERTICAL);
-  panelSizer->Add(lektionsSizer,0,wxALL,5);
+  panelSizer->Add(lektionsSizer,1,wxEXPAND|wxALL,5);
 
   //final steps to the panel
   panel->SetSizer(panelSizer);
@@ -119,46 +122,31 @@ wxPanel* Lektionsauswahl::getIncludedLessonPage (wxWindow* parent) {
 }
 
 wxListBox* Lektionsauswahl::getIncludedLessonListBox (wxWindow* parent, int id) {
-  //loading lessons index
-  LessonDir filename;
-  wxString* tlayout = TtConfigFile::getPtr()->getKeyboardLayout();
-  filename.AppendDir(*tlayout);
-  delete tlayout;
-  filename.SetFullName(_T("lektion.index"));
-
-  wxFFileInputStream input(filename.GetFullPath());
-  if (!input.Ok()) {
-    ::wxLogError(_("Cannot load file %s"), filename.GetFullName().c_str());
-    EndModal(wxID_CANCEL);
+  wxListBox* retval;
+  LessonPath filename;
+  filename.appendDir(TtConfigFile::getPtr()->getKeyboardLayout());
+  filename.setFullFileName(_T("lektion.index"));
+  wxURL* u = filename.getURL();
+  wxInputStream* input = common::getInputStream(*u);
+  if (input==0) {
+    ::wxLogError(_("Cannot load file %s"), filename.getFullFileName().c_str());
+    retval = new wxListBox(parent, id, wxDefaultPosition, wxDefaultSize,
+			 0, NULL, wxLB_SINGLE|wxLB_NEEDED_SB);
   } else {
-    wxTextInputStream f(input);
-    wxString content;
-    while(!input.Eof()) {
-      content=f.ReadLine();
-      if (!input.Eof()) {
-	ar.Add(content);
-      }
-    }
-    //convert the wxArrayString to a wxString[]
-    //they are not copied, so the wxArrayString _must_ stay valid
-    choices = new wxString*[ar.GetCount()];
-    for (unsigned int i=0;i<ar.GetCount();++i) {
-      choices[i]=&ar[i];
-    }
+    this->ar = common::getIndexFile(*input);
+    retval = new wxListBox(parent, id, wxDefaultPosition, wxDefaultSize,
+			   ar.GetCount(), common::toStringPtr(this->ar),
+			   wxLB_SINGLE|wxLB_NEEDED_SB);
   }
-  //end loading lessons index
-
-  return new wxListBox(parent, id, wxDefaultPosition, wxDefaultSize,
-		       ar.GetCount(), *choices, wxLB_SINGLE|wxLB_NEEDED_SB);
+  delete input;
+  delete u;
+  return retval;
 }
 
 Lektionsauswahl::~Lektionsauswahl () {
-  delete lb;
-  delete st;
-  delete sb;
 }
 
-void Lektionsauswahl::OnLektionStarten (wxCommandEvent* event) {
+void Lektionsauswahl::OnLektionStarten (wxCommandEvent& event) {
   if (lb->GetSelection() != -1) {
     EndModal(GetReturnCode());
   } else {
@@ -166,7 +154,7 @@ void Lektionsauswahl::OnLektionStarten (wxCommandEvent* event) {
   }
 }
 
-void Lektionsauswahl::OnListBox (wxCommandEvent* event) {
+void Lektionsauswahl::OnListBox (wxCommandEvent& event) {
   this->lastselection=lb->GetSelection();
   LEntry* entry = TtConfigFile::getPtr()->loadLessonData(this->lastselection+1);
   if (entry!=NULL) {
