@@ -28,8 +28,8 @@ class Lektionsauswahl : public wxDialog {
   Lektionsauswahl(wxWindow* parent);
   ~Lektionsauswahl();
   // Event Handler
-  void OnLektionStarten(wxCommandEvent* event);
-  void OnListBox(wxCommandEvent* event);
+  void OnLektionStarten(wxCommandEvent& event);
+  void OnListBox(wxCommandEvent& event);
   // andere Funktionen
   inline int GetLektion() { return lb->GetSelection() + 1; };
 
@@ -37,7 +37,6 @@ class Lektionsauswahl : public wxDialog {
   wxButton* btnOk;
   wxButton* btnCancel;
   wxArrayString ar;
-  wxString** choices; //don't delete in destructor???
   wxListBox* lb;
   wxStaticBox* sb;
   wxStaticBoxSizer* sbSizer; //don't delete in destructor!
