@@ -15,22 +15,22 @@
 #include "dirs.H"
 #include "lektionsauswertung.h"
 #include "LessonStatusSizer.H"
+#include "commonElements.H"
 #include <wx/statline.h>
 
 lauswertung::lauswertung(wxWindow *parent, const wxString& title, Lektion* lektion)
   : wxDialog(parent, -1, title)
 {
-  LessonDir f;
-  f.SetFullName(_T("logo.png"));
-  wxBitmap logo(f.GetFullPath(), wxBITMAP_TYPE_PNG);
-  wxStaticBitmap *icon = new wxStaticBitmap(this, -1, logo);
+  wxBitmap* logo = common::getLogo();
 
   LessonStatusSizer* statusSizer = new LessonStatusSizer(this);
   LEntry entry = lektion->GetLessonData();
   statusSizer->setStatus(entry);
 
   wxBoxSizer* subSizer = new wxBoxSizer(wxHORIZONTAL);
-  subSizer->Add(icon,0,wxLEFT|wxRIGHT|wxTOP,10);
+  if (logo != 0) {
+    subSizer->Add(new wxStaticBitmap(this, -1, *logo),0,wxLEFT|wxRIGHT|wxTOP,10);
+  }
   subSizer->Add(statusSizer,0,wxALIGN_CENTER|wxRIGHT|wxTOP,10);
   
   
