@@ -1,44 +1,25 @@
 /***************************************************************************
-                          lektionsauswertung.h  -  description                              
-                             -------------------                                         
-    begin                : Tue Feb  1 21:30:13 MET 2000 
-                                           
-    copyright            : (C) 1999 by Daniel Reith                         
-    email                : DanR@gmx.de
-	
- ***************************************************************************/
-
-/***************************************************************************
+ *   copyright            : (C) 1999 by Daniel Reith                       *
+ *   email                : DanR@gmx.de                                    *
+ *                                                                         *
+ *   copyright           : (C) 2003 by Hendrik Sattler                     *
+ *   mail                : pingos@hendrik-sattler.de                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
 #ifndef L_AUSWERTUNG_H
 #define L_AUSWERTUNG_H
 
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
+#include "lektion.h"
 #include <wx/wx.h>
 
-#include "lektion.h"
-
-class lauswertung : public wxDialog
-{
-  DECLARE_EVENT_TABLE()
-private:
-  
- public:
+class lauswertung : public wxDialog {
+public:
   lauswertung(wxWindow *parent, const wxString& title, Lektion* lektion);
-  
-  void OnSchliessen(wxCommandEvent* event);
 };
-
-
 #endif
