@@ -14,18 +14,20 @@
 
 #include "dirs.H"
 #include "main.h"
-#include "lektion.h"
-#include "kurs.h"
 #include "info.h"
+#include "ConfigFile.H"
 #include "optionen.h"
 #include "auswahl.h"
-#include "ConfigFile.H"
-#include "../config.h"
 #include <wx/fontdlg.h>
 #include <wx/font.h>
+#include <wx/image.h>
+#include <wx/tooltip.h>
 
-// Icon
-#if defined(__WXGTK__) || defined(__WXMOTIF__)
+#ifndef __VISUALC__
+#  include "../config.h"
+#endif
+
+#ifndef __WXMSW__
 #  include "logo.xpm"
 #endif
 
@@ -47,65 +49,102 @@ END_EVENT_TABLE()
 
 IMPLEMENT_APP(tipptrainer)
 
+int current_lang = 0;
+
+void tipptrainer::localize () {
+  //i18n
+  //get setting from system
+  int syslang = wxLocale::GetSystemLanguage();
+  //get setting from configuration file
+  wxString lang = TtConfigFile::getPtr()->getLanguage();
+
+  bool translation_warning = false;
+  int i = 0;
+  if (lang == _T("")) {
+    /* set the programs locale according to the systems locale
+     * but only if listed as supported
+     */
+    while (supported_langs[i].name != _T("")) {
+      if (syslang >= supported_langs[i].locale_min &&
+	  syslang <= supported_langs[i].locale_max) {
+	if (i > 0) {
+	  translation_warning = true;
+	}
+	{
+	  wxLogNull l;
+	  m_locale.Init(wxLANGUAGE_DEFAULT,wxLOCALE_CONV_ENCODING);
+	}
+	break;
+      }
+      ++i;
+    }
+  } else {
+    /* set the programs locale to the forced value
+     */
+    int lindex_min = syslang;
+    int lindex_max = syslang;
+    while (supported_langs[i].name != _T("")) {
+      if (supported_langs[i].name == lang) {
+	lindex_min = supported_langs[i].locale_min;
+	lindex_max = supported_langs[i].locale_max;
+	break;
+      }
+      ++i;
+    }
+    if (lindex_min <= syslang && syslang <= lindex_max) {
+      //current system locale matches wanted one
+      {
+	wxLogNull l;
+	m_locale.Init(wxLANGUAGE_DEFAULT,wxLOCALE_CONV_ENCODING);
+      }
+    } else if (i > 0) {
+      //language is not english (compiled-in lang)
+      translation_warning = true;
+      //find the right locale to load
+      for (int k=lindex_min;k<=lindex_max;++k) {
+	if (!m_locale.IsOk()) {
+	  {
+	    wxLogNull l;
+	    m_locale.Init(k,wxLOCALE_CONV_ENCODING);
+	  }
+	}
+      }
+    }
+  }
+  if (supported_langs[i].name != _T("")) {
+    current_lang = i;
+  }
+
+  if (!m_locale.IsOk()) {
+    if (translation_warning) {
+      ::wxLogError(wxString(_T("The translation file loader needs an installed locale.")));
+    }
+  } else {
+    /* Loading gettext (.mo) files does only work when a locale was loaded.
+     * Overriding compiled in texts is even enabled for english texts
+     * but warnings are only issued for foreign languages.
+     */
+    LangDir l;
+    m_locale.AddCatalogLookupPathPrefix(l.GetFullPath());
+    if (!m_locale.AddCatalog(_T("wxstd")) && translation_warning) {
+      ::wxLogError(wxString(_T("Could not load wxWindows translation file.")));
+    }
+    if (!m_locale.AddCatalog(_T("tipptrainer")) && translation_warning) {
+      ::wxLogError(wxString(_T("Could not load Tipptrainer translation file.")));
+    }
+  }
+}
+
 bool tipptrainer::OnInit () {
   SetVendorName(_T("Pingos"));
   SetAppName(_T("Tipptrainer"));
 
   ::wxInitAllImageHandlers();
+  unsigned int seconds = TtConfigFile::getPtr()->getToolTipDelay();
+  wxToolTip::Enable(true);
+  wxToolTip::SetDelay(seconds*1000);
 
-  // Internationalisierung
-  wxString* lang = TtConfigFile::getPtr()->getLanguage();
-  int syslang = wxLocale::GetSystemLanguage();
-  LangDir l;
-  if (*lang == _T("german")) {
-    // only using wxLANGUAGE_GERMAN does not work
-    switch (syslang) {
-    case wxLANGUAGE_GERMAN_AUSTRIAN:
-    case wxLANGUAGE_GERMAN_BELGIUM:
-    case wxLANGUAGE_GERMAN_LIECHTENSTEIN:
-    case wxLANGUAGE_GERMAN_LUXEMBOURG:
-    case wxLANGUAGE_GERMAN_SWISS:
-      m_locale.Init(syslang);
-      break;
-    default:
-      m_locale.Init(wxLANGUAGE_GERMAN);
-      break;
-    }
-    m_locale.AddCatalogLookupPathPrefix(l.GetFullPath());
-    if (m_locale.AddCatalog(_T("tipptrainer")) == false) {
-      // translation makes no sense
-      // Maybe it should be in German? Has to be ASCII, though.
-      ::wxLogError( wxString(_T("Could not load german gettext translation file.\n"))
-		   +wxString(_T("This means that all texts that are not external resouces\n"))
-		   +wxString(_T("will be English.")));
-    }
-  } else {
-    // only using wxLANGUAGE_ENGLISH does not work
-    switch (syslang) {
-    case wxLANGUAGE_ENGLISH_UK:
-    case wxLANGUAGE_ENGLISH_US:
-    case wxLANGUAGE_ENGLISH_AUSTRALIA:
-    case wxLANGUAGE_ENGLISH_BELIZE:
-    case wxLANGUAGE_ENGLISH_BOTSWANA:
-    case wxLANGUAGE_ENGLISH_CANADA:
-    case wxLANGUAGE_ENGLISH_CARIBBEAN:
-    case wxLANGUAGE_ENGLISH_DENMARK:
-    case wxLANGUAGE_ENGLISH_EIRE:
-    case wxLANGUAGE_ENGLISH_JAMAICA:
-    case wxLANGUAGE_ENGLISH_NEW_ZEALAND:
-    case wxLANGUAGE_ENGLISH_PHILIPPINES:
-    case wxLANGUAGE_ENGLISH_SOUTH_AFRICA:
-    case wxLANGUAGE_ENGLISH_TRINIDAD:
-    case wxLANGUAGE_ENGLISH_ZIMBABWE:
-      m_locale.Init(syslang);
-      break;
-    default:
-      // we cannot make sure that the user actually want a locale
-      // since the text language in this code in English,
-      // none is really needed
-      break;
-    }
-  }
+  localize();
 
   Hauptfenster *h = new Hauptfenster(); 
   SetTopWindow(h);
@@ -114,7 +153,7 @@ bool tipptrainer::OnInit () {
 };
 
 int tipptrainer::OnExit () {
-  delete wxConfigBase::Set((wxConfigBase *) NULL);
+  delete TtConfigFile::getPtr();
   return 0;
 }
 
@@ -136,68 +175,63 @@ Hauptfenster::Hauptfenster ()
   // ******************************************
   MainMenu = new wxMenuBar;
 
-  DateiMenu = new wxMenu;
-  DateiMenu->Append(D_LPause, _("&Pause"),
+  FileMenu = new wxMenu;
+  FileMenu->Append(D_LPause, _("&Pause"),
 		    _("Pauses the current lesson"));
-  DateiMenu->Append(D_LektionBeenden, _("&Abort"),
+  FileMenu->Append(D_LektionBeenden, _("&Abort"),
 		    _("Cancels the current lesson|class|contest"));
-  DateiMenu->AppendSeparator();
-  DateiMenu->Append(D_LektionLaden, _("&Lesson..."), /* never to be disabled */
-		    _("Shows the lesson selection dialog"));
-  DateiMenu->Append(D_KLaden, _("&Class..."), /* never to be disabled */
-		    _("Show the class selection dialog"));
-  DateiMenu->AppendSeparator();
-  DateiMenu->Append(D_Beenden, _("E&xit"), /* never to be disabled */
+  FileMenu->AppendSeparator();
+  FileMenu->Append(D_Beenden, _("E&xit"), /* never to be disabled */
 		    _("Terminates the tipptrainer"));
   //default is an enabled menu item but not all should be
-  DateiMenu->Enable(D_LektionBeenden, FALSE);
-  DateiMenu->Enable(D_LPause, FALSE);
+  FileMenu->Enable(D_LektionBeenden, FALSE);
+  FileMenu->Enable(D_LPause, FALSE);
 
-
-  ContestMenu = new wxMenu;
-  ContestMenu->Append(C_RunContest,_("&Do the contest..."),
-		      _("Runs the contest start wizard"));
-  ContestMenu->Append(C_ShowRanking,_("Show Ranking..."),
-		      _("Displays the ranking for the current contest"));
-  ContestMenu->AppendSeparator();
-  ContestMenu->Append(C_EditContest,_("Contest editor..."),
-		      _("Select/add/remove/edit contests"));
   bool hasContests = TtConfigFile::getPtr()->contestsExist();
-  ContestMenu->Enable(C_RunContest,hasContests);
-  ContestMenu->Enable(C_ShowRanking,hasContests);
 
-  OptionenMenu = new wxMenu;
-  OptionenMenu->AppendCheckItem(O_SwitchBell,_("&Beep on error"),/* never to be disabled */
+  ModesMenu = new wxMenu;
+  ModesMenu->Append(D_LektionLaden, _("&Lesson..."), /* never to be disabled */
+		    _("Shows the lesson selection dialog"));
+  ModesMenu->Append(D_KLaden, _("&Class..."), /* never to be disabled */
+		    _("Show the class selection dialog"));
+  ModesMenu->Append(C_RunContest,_("&Do the contest..."),
+		      _("Runs the contest start wizard"));
+  ModesMenu->Enable(C_RunContest,hasContests);
+
+  ViewMenu = new wxMenu;
+  ViewMenu->Append(C_ShowRanking,_("Contest &Ranking..."),
+		      _("Displays the ranking for the current contest"));
+  ViewMenu->Enable(C_ShowRanking,hasContests);
+
+  OptionsMenu = new wxMenu;
+  OptionsMenu->AppendCheckItem(O_SwitchBell,_("&Beep on error"),/* never to be disabled */
 				_("Beep on type errors on/off"));
-  OptionenMenu->Append(O_Schriftwaehlen, _("Select &font..."), /* never to be disabled */
+  OptionsMenu->Append(O_Schriftwaehlen, _("Select &font..."), /* never to be disabled */
 		       _("Show the font selection dialog"));
-  OptionenMenu->Append(O_Einstellungen, _("&Settings..."), /* never to be disabled */
-		       _("Shows the settings dialog"));
+  OptionsMenu->Append(C_EditContest,_("Contest &editor..."),
+		      _("Select/add/remove/edit contests"));
+  OptionsMenu->Append(O_Einstellungen, _("&Configure Tipptrainer..."), /* never to be disabled */
+		       _("Shows the configuration dialog"));
   //setting defaults for some menu items
-  OptionenMenu->Check(O_SwitchBell,TtConfigFile::getPtr()->getBellStatus());
+  OptionsMenu->Check(O_SwitchBell,TtConfigFile::getPtr()->getBellStatus());
 
 
-  HilfeMenu = new wxMenu;
-  HilfeMenu->Append(Hilfe_Info, _("A&bout..."),  /* never to be disabled */
+  HelpMenu = new wxMenu;
+  HelpMenu->Append(Hilfe_Info, _("A&bout..."),  /* never to be disabled */
 		    _("Show information about the Tipptrainer team"));
   
-  MainMenu->Append(DateiMenu, _("&File"));
-  MainMenu->Append(ContestMenu, _("&Contest"));
-  MainMenu->Append(OptionenMenu, _("&Options"));
-  MainMenu->Append(HilfeMenu, _("&Help"));
+  MainMenu->Append(FileMenu, _("&File"));
+  MainMenu->Append(ModesMenu, _("&Modes"));
+  MainMenu->Append(ViewMenu, _("&View"));
+  MainMenu->Append(OptionsMenu, _("&Settings"));
+  MainMenu->Append(HelpMenu, _("&Help"));
   
   // Menubar dem Hauptfenster zuweisen
   SetMenuBar(MainMenu);
 
   // Statusbar erzeugen
-  CreateStatusBar(4);
-  int i[4]={-1, 100, 110, 100};
-  SetStatusWidths(4, i);
-  // Statusbartext setzten
+  CreateStatusBar(1);
   SetStatusText(_("Welcome to PingoS Tipptrainer"),0);
-  SetStatusText(_T(""), 1);
-  SetStatusText(_T(""),2);
-  SetStatusText(_T(""),3);
 
   // SplitterWindow erzeugen
   sw = new wxSplitterWindow(this, 1);
@@ -265,23 +299,61 @@ void Hauptfenster::OnO_Einstellungen (wxCommandEvent& event) {
   od.ShowModal();
 }
 
+bool Hauptfenster::setLessonController(LessonController* c, bool deleteOld) {
+  if (this->lcontrol != 0 && deleteOld) {
+    int answer = wxYES;
+    if (this->lcontrol->runningLesson()) {
+      wxString s;
+      s.Printf(_("Abort current %s?"),this->lcontrol->getType().c_str());
+      answer = wxMessageBox(s,_("Abort request"),wxYES_NO,this);
+    }
+    if (answer==wxYES) {
+      delete this->lcontrol;
+    } else {
+      return false;
+    }
+  }
+  this->lcontrol=c;
+  FileMenu->Enable(D_LektionBeenden, (this->lcontrol != 0));
+  return true;
+}
+
+void Hauptfenster::OnO_Schriftwaehlen (wxCommandEvent& event) {
+  wxFont oldFont = TtConfigFile::getPtr()->getMainWindowFont();
+  //we could do our own wxFontDialog but why?
+  //somehow, the initial font stuff does not work :-(
+  wxFont chosenFont = ::wxGetFontFromUser(this, oldFont);
+
+  if (chosenFont.Ok()) {
+    this->GetInput()->setFont(chosenFont);
+    this->GetOutput()->setFont(chosenFont);
+    TtConfigFile::getPtr()->setMainWindowFont(chosenFont);
+  }
+}
+
+void Hauptfenster::OnO_SwitchBell (wxCommandEvent& WXUNUSED(event)) {
+  TtConfigFile::getPtr()->toggleBellStatus();
+}
+
+#include "SingleLesson.H"
 void Hauptfenster::OnLektionLaden (wxCommandEvent& event) {
   try {
-    new Lektion();
+    new SingleLesson(this);
   }
   catch (LessonController::Abbruch) {
+    setLessonController(0,false);
   }
   catch (Lektion::LessonLoadedFailed) {
     setLessonController(0,false);
   }
 }
 
+#include "kurs.h"
 void Hauptfenster::OnD_KursLaden (wxCommandEvent& event) {
   try {
     new Kurs(this);
   }
   catch (LessonController::Abbruch) {
-    setLessonController(0,false);
   }
   catch (Kurs::DialogAborted) {
     setLessonController(0,false);
@@ -291,53 +363,13 @@ void Hauptfenster::OnD_KursLaden (wxCommandEvent& event) {
   }
 }
 
-bool Hauptfenster::setLessonController(LessonController* c, bool deleteOld) {
-  if (this->lcontrol == 0 || !deleteOld) {
-    this->lcontrol=c;
-  } else {
-    if (this->lcontrol->runningLesson()) {
-      wxString s;
-      s.Printf(_("Abort current %s?"),this->lcontrol->getType().c_str());
-      int answer = wxMessageBox(s,_("Abort request"),wxYES_NO,this);
-      if (answer==wxYES) {
-	delete this->lcontrol;
-	this->lcontrol=c;
-      } else {
-	return false;
-      }
-    } else {
-      delete this->lcontrol;
-      this->lcontrol=c;
-    }
-  }
-  DateiMenu->Enable(D_LektionBeenden, (this->lcontrol != 0));
-  return true;
-}
-
-void Hauptfenster::OnO_Schriftwaehlen (wxCommandEvent& event) {
-  wxFont* oldFont = TtConfigFile::getPtr()->getMainWindowFont();
-  //we could do our own wxFontDialog but why?
-  //somehow, the initial font stuff does not work :-(
-  wxFont chosenFont = ::wxGetFontFromUser(this, *oldFont);
-  if (chosenFont.Ok()) {
-    this->GetInput()->setFont(chosenFont);
-    this->GetOutput()->setFont(chosenFont);
-    TtConfigFile::getPtr()->setMainWindowFont(chosenFont);
-  }
-  delete oldFont;
-}
-
-void Hauptfenster::OnO_SwitchBell (wxCommandEvent& WXUNUSED(event)) {
-  TtConfigFile::getPtr()->toggleBellStatus();
-}
-
+#include "Contest.H"
 void Hauptfenster::OnC_RunContest(wxCommandEvent& event){
   ContestDesc c = TtConfigFile::getPtr()->getContest(TtConfigFile::getPtr()->getSelectedContestId());
   try {
     new Contest(this,c);
   }
   catch(LessonController::Abbruch) {
-    setLessonController(0,false);
   }
   catch (Lektion::LessonLoadedFailed) {
     setLessonController(0,false);
@@ -345,7 +377,6 @@ void Hauptfenster::OnC_RunContest(wxCommandEvent& event){
 }
 
 #include "ContestRankingDlg.H"
-
 void Hauptfenster::OnC_ShowRanking(wxCommandEvent& WXUNUSED(event)){
   ContestDesc c = TtConfigFile::getPtr()->getContest(TtConfigFile::getPtr()->getSelectedContestId());
   ContestRankingDlg ranking(this,c.title,c.dataFile,c.weight);
@@ -353,11 +384,10 @@ void Hauptfenster::OnC_ShowRanking(wxCommandEvent& WXUNUSED(event)){
 }
 
 #include "ContestSelectDlg.H"
-
 void Hauptfenster::OnC_EditContest(wxCommandEvent& WXUNUSED(event)){
   ContestSelectDlg* dialog = new ContestSelectDlg(this);
   dialog->ShowModal();
   bool hasContests = TtConfigFile::getPtr()->contestsExist();
-  ContestMenu->Enable(C_RunContest,hasContests);
-  ContestMenu->Enable(C_ShowRanking,hasContests);
+  ModesMenu->Enable(C_RunContest,hasContests);
+  ViewMenu->Enable(C_ShowRanking,hasContests);
 }
