@@ -30,9 +30,13 @@ class tipptrainer : public wxApp {
   virtual bool OnInit();
   virtual int OnExit();
  private:
-  wxLocale m_locale;	
+  wxLocale m_locale;
+  void localize();
 };
 
+class TtInputControl;
+class TtOutputControl;
+
 class Hauptfenster : public wxFrame {
  public:
   Hauptfenster();
@@ -64,7 +68,7 @@ class Hauptfenster : public wxFrame {
   bool setLessonController(LessonController* c, bool deleteOld = true);
   inline LessonController* getLessonController() { return this->lcontrol; };
 
-  inline wxMenu* GetDateiMenu() { return DateiMenu; };
+  inline wxMenu* GetFileMenu() { return FileMenu; };
   inline TtOutputControl* GetOutput() { return (TtOutputControl*)this->sw->GetWindow1(); };
   inline TtInputControl* GetInput() { return  (TtInputControl*)this->sw->GetWindow2(); };
 		
@@ -73,10 +77,11 @@ class Hauptfenster : public wxFrame {
 
   wxSplitterWindow* sw;
   wxMenuBar* MainMenu;
-  wxMenu*     DateiMenu;
-  wxMenu*     ContestMenu;
-  wxMenu*     OptionenMenu;
-  wxMenu*     HilfeMenu;
+  wxMenu*     FileMenu;
+  wxMenu*     ModesMenu;
+  wxMenu*     ViewMenu;
+  wxMenu*     OptionsMenu;
+  wxMenu*     HelpMenu;
 
   LessonController* lcontrol;
 
