@@ -15,23 +15,32 @@
 #ifndef OPTIONEN_H
 #define OPTIONEN_H
 
-#include "wx/wx.h"
+#include "UrlSelectPanel.H"
+#include <wx/wx.h>
+#include <wx/checkbox.h>
 
 class ODialog: public wxDialog {
- public:
+public:
   ODialog(wxWindow* parent);
   ~ODialog();
   
-  void OnOK(wxCommandEvent* event);
-  
- private:
-  wxStaticText descr1;
-  wxComboBox* selection1;
-  wxStaticText descr2;
-  wxComboBox* selection2;
-  wxButton btnSave;
-  wxButton btnCancel;
-  
+private:
+  wxCheckBox* langOverride;
+  wxComboBox* langSel;
+  wxCheckBox* keybOverride;
+  wxComboBox* keybSel;
+  wxCheckBox* dataOverride;
+  UrlSelectPanel* url;
+
+  wxPanel* getDataLocationPage (wxWindow* parent);
+  wxSizer* getSourceSizer (wxWindow* parent);
+  wxPanel* getLocalizationPage (wxWindow* parent);
+  wxComboBox* getLangSelector (wxWindow* parent);
+  wxComboBox* getKeyboardSelector (wxWindow* parent);
+
+  void OnSave(wxCommandEvent& event);
+  void OnCheckBox (wxCommandEvent& event);
+
   DECLARE_EVENT_TABLE()
 };
 
