@@ -15,6 +15,8 @@
 #ifndef OUTPUTCONTROL_H
 #define OUTPUTCONTROL_H
 
+#include "dirs.H"
+#include "lektion.h"
 #include <wx/wx.h>
 
 class TtOutputControl : public wxTextCtrl {
@@ -30,10 +32,18 @@ public:
   void setFont (wxFont& newFont);
   inline wxFont* getFont () { return localfont; };
 
-  bool LoadFile (const wxString& filename);
-  void highlightChar (long line, long column);
+  bool LoadLesson (UrlFile& lesson);
+  void highlightFirstChar ();
+  void highlightNextChar (unsigned int i = 1, bool newline = false);
+  long getHighlightPosition () { return this->highlightCharPos; };
 
-  long getHighlightPosition() { return this->highlightCharPos; };
+  wxUChar getSpecialLineEnd () { return this->specialLineEnd; };
+/*   void highlightChar (unsigned long line, unsigned long column); */
+/*   long XYToPosition(long column, long line); */
+
+  void fillFromCache ();
+  void updateHighlightPos ();
+  void SetSelection(long from, long to);
 
 private:
   wxFont* localfont;
@@ -41,9 +51,9 @@ private:
   wxColour* bgcolor;
 
   long highlightCharPos;
-  bool specialLineEndingChar;
-  wxString fname;
+  wxUChar specialLineEnd;
 
+  void highlightChar ();
   void updateLook ();
 
   DECLARE_EVENT_TABLE()
